translate.storage.placeables.strelem

Package translate :: Package storage :: Package placeables :: Module strelem |
[hide private]
[frames] | no frames]

# Module strelem

source code

Contains the base StringElem class that represents a node in a parsed rich- string tree. It is the base class of all placeables.

Classes | [hide private]
| ElementNotFoundError
| StringElem This class represents a sub-tree of a string parsed into a rich structure.

Imports: logging, sys